Learn R Programming

SpeTestNP (version 1.1.0)

print.STNP: Print a specification test STNP object

Description

Prints the test statistic and p-value of a specification test object of class STNP

Usage

# S3 method for STNP
print(x, ...)

Value

No return value, prints the test statistic and p-value

Arguments

x

An object of class STNP resulting from function SpeTest

...

Additional print arguments

Author

Hippolyte Boucher <Hippolyte.Boucher@outlook.com>

Pascal Lavergne <lavergnetse@gmail.com>

See Also

SpeTest is the function which performs a specification test and records it along with all its options in an object of class STNP

summary.STNP prints a summary of the specification test with all the options used

Examples

Run this code
n <- 100
k <- 2
x <- matrix(rnorm(n*k),ncol=k)
y<-1+x%*%(1:k)+rnorm(n)

eq<-lm(y~x+0)


print(SpeTest(eq=eq,type="icm",nboot=50))

Run the code above in your browser using DataLab