powered by
STNP
Prints the test statistic and p-value of a specification test object of class STNP
# S3 method for STNP print(x, ...)
No return value, prints the test statistic and p-value
An object of class STNP resulting from function SpeTest
SpeTest
Additional print arguments
Hippolyte Boucher <Hippolyte.Boucher@outlook.com>
Pascal Lavergne <lavergnetse@gmail.com>
SpeTest is the function which performs a specification test and records it along with all its options in an object of class STNP
summary.STNP prints a summary of the specification test with all the options used
summary.STNP
n <- 100 k <- 2 x <- matrix(rnorm(n*k),ncol=k) y<-1+x%*%(1:k)+rnorm(n) eq<-lm(y~x+0) print(SpeTest(eq=eq,type="icm",nboot=50))
Run the code above in your browser using DataLab